@@ -3,7 +3,7 @@
 # https://github.com/thomasp85/patchwork/issues/379). Therefore, ggalign will
 # retain `alignpatch-*` scripts.
 
-#' Define the plotting areas in `align_plots`
+#' Define the plotting areas
 #'
 #' @inherit patchwork::area
 #' @details
@@ -88,6 +88,9 @@ S3_area <- S7::new_S3_class("ggalign_area")
 
 new_areas <- function(x) new_rcrd(x, class = c("ggalign_area", "patch_area"))
 
+#' @export
+c.ggalign_area <- function(...) vec_c(...)
+
 create_area <- function(ncol, nrow, byrow) {
     mat <- matrix(seq_len(ncol * nrow),
         nrow = nrow, ncol = ncol, byrow = byrow
@@ -99,12 +102,12 @@ create_area <- function(ncol, nrow, byrow) {
 
 #' @export
 obj_print_data.ggalign_area <- function(x, ...) {
-    x <- vec_data(x)
     if (vec_size(x) > 0) {
-        x <- vec_set_names(x, paste0(vec_seq_along(x), ": "))
-        print(x = x, ..., quote = FALSE)
+        data <- vec_data(x)
+        data <- vec_set_names(data, paste0(vec_seq_along(data), ": "))
+        print(x = data, ..., quote = FALSE)
     } else {
-        cat("   ", names(x), "\n", sep = " ")
+        cat("   ", "\n", sep = " ")
     }
 }
 
@@ -134,6 +137,9 @@ trim_area <- function(area) {
     new_areas(area)
 }
 
+#' Convert object into a design area
+#' @keywords internal
+#' @noRd
 as_areas <- function(x) UseMethod("as_areas")
 
 #' @export
@@ -141,9 +147,6 @@ as_areas.default <- function(x) {
     cli_abort("Cannot convert {.obj_type_friendly {x}} into a design area")
 }
 
-#' @export
-as_areas.NULL <- function(x) NULL
-
 #' @export
 as_areas.ggalign_area <- function(x) x
 
@@ -177,7 +180,7 @@ as_areas.character <- function(x) {
         r <- .subset(area_cols, 2L)
         if (!all(x[row >= t & row <= b & col >= l & col <= r] ==
             x[.subset(i, 1L)])) {
-            cli_abort("Patch areas must be rectangular", call = call)
+            cli_abort("Design areas must be rectangular", call = call)
         }
         new_areas(list(t = t, l = l, b = b, r = r))
     })
@@ -186,7 +189,7 @@ as_areas.character <- function(x) {
 
 # For area from patchwork
 #' @export
-as_areas.patch_area <- function(x) add_class(x, "ggalign_area")
+as_areas.patch_area <- function(x) new_areas(unclass(x))
 
 #' @importFrom grid unit
 #' @importFrom ggplot2 aes margin theme ggplot
@@ -208,10 +211,14 @@ plot.ggalign_area <- function(x, ...) {
         lim[-c(1, length(lim))]
     }
     ggplot(data) +
-        ggplot2::geom_rect(aes(
-            xmin = .data$l, xmax = .data$r,
-            ymin = .data$t, ymax = .data$b, fill = .data$name
-        ), alpha = 0.3) +
+        ggplot2::geom_rect(
+            aes(
+                xmin = .data$l, xmax = .data$r,
+                ymin = .data$t, ymax = .data$b,
+                fill = .data$name
+            ),
+            alpha = 0.3
+        ) +
         ggplot2::scale_y_reverse(breaks = b_fun, expand = c(0, 0.04)) +
         ggplot2::scale_x_continuous(
             breaks = b_fun, expand = c(0, 0.04), position = "top"
