@@ -1,7 +1,8 @@
 ########################################
 #' @importFrom utils modifyList getFromNamespace
+#' @importFrom S7 convert
 #' @export
-alignpatch.patchwork <- function(x) {
+patch.patchwork <- function(x) {
     rlang::check_installed("patchwork", "to align patchwork")
     get_patches <- getFromNamespace("get_patches", "patchwork")
     # patchwork will keep the class when extracting patches from it.
@@ -13,28 +14,19 @@ alignpatch.patchwork <- function(x) {
         class(x) <- class(x)[-seq_len(sub_patchwork_cls)]
     }
     x <- get_patches(x)
-    plots <- .subset2(x, "plots")
     layout <- .subset2(x, "layout")
     annotation <- .subset2(x, "annotation")
     default <- getFromNamespace("default_layout", "patchwork")
     layout <- modifyList(default, layout[
         !vapply(layout, is.null, logical(1L), USE.NAMES = FALSE)
     ])
-    if (identical(.subset2(layout, "guides"), "collect")) {
-        layout$guides <- .TLBR
-    } else {
-        layout$guides <- NULL
-    }
-    alignpatch(AlignPatches(
-        plots,
-        layout = layout,
-        titles = .subset(annotation, names(layout_title())),
-        theme = .subset2(annotation, "theme")
-    ))
+    plots <- .subset2(x, "plots")
+    plot <- alignpatches(!!!plots)
+    patch(plot + layout + annotation)
 }
 
 #' @export
-alignpatch.free_plot <- function(x) {
+patch.free_plot <- function(x) {
     if (inherits(x, "patchwork")) {
         free_settings <- attr(x, "patchwork_free_settings")
     } else {
@@ -53,30 +45,34 @@ alignpatch.free_plot <- function(x) {
             space = free_space(free_border(x, side), side),
         )
     }
-    alignpatch(x)
+    patch(x)
 }
 
 ######################################
 # `patch` from `patchwork`: patchwork::plot_spacer
 #' @importFrom ggplot2 ggproto
 #' @export
-alignpatch.patch <- function(x) {
+patch.patch <- function(x) {
     rlang::check_installed(
         "patchwork", sprintf("to align %s plot", obj_type_friendly(x))
     )
-    ggproto(NULL, PatchPatchworkPatch, patch = x)
+    ggproto(NULL, PatchPatchworkPatch, plot = x)
 }
 
+# `patch` from `patchwork`: patchwork::wrap_elements
+#' @export
+patch.wrapped_patch <- patch.patch
+
 #' @importFrom ggplot2 ggproto
 PatchPatchworkPatch <- ggproto(
     "PatchPatchworkPatch", Patch,
     # `patch` from `patchwork`: patchwork::plot_spacer
     #' @importFrom gtable gtable_add_rows gtable_add_cols
     #' @importFrom ggplot2 find_panel
-    patch_gtable = function(self, theme = NULL, guides = NULL, tagger = NULL) {
+    gtable = function(self, theme = NULL, guides = NULL, tagger = NULL) {
         guides <- if (length(guides)) "collect" else "keep"
-        ans <- patchwork::patchGrob(self$patch, guides = guides)
-        # add rows and columns for `patch_titles()`
+        ans <- patchwork::patchGrob(self$plot, guides = guides)
+        # add rows and columns for `patch_title()`
         for (border in .TLBR) {
             panel_pos <- find_panel(ans)
             if (border == "top") {
@@ -101,9 +97,4 @@ PatchPatchworkPatch <- ggproto(
 )
 
 #' @export
-alignpatch.spacer <- function(x) NULL
-
-#########################################
-# `patch` from `patchwork`: patchwork::wrap_elements
-#' @export
-alignpatch.wrapped_patch <- alignpatch.patch
+patch.spacer <- function(x) NULL
