@@ -1,3 +1,61 @@
+#' Annotate the whole layout
+#'
+#' @inheritParams ggplot2::labs
+#' @return A `layout_title` object.
+#' @examples
+#' p1 <- ggplot(mtcars) +
+#'     geom_point(aes(mpg, disp))
+#' p2 <- ggplot(mtcars) +
+#'     geom_boxplot(aes(gear, disp, group = gear))
+#' p3 <- ggplot(mtcars) +
+#'     geom_bar(aes(gear)) +
+#'     facet_wrap(~cyl)
+#' align_plots(p1, p2, p3) +
+#'     layout_title(title = "I'm title")
+#' @importFrom ggplot2 waiver
+#' @include utils-ggplot.R
+#' @export
+layout_title <- S7::new_class("layout_title",
+    properties = lapply(
+        rlang::set_names(c("title", "subtitle", "caption")),
+        function(type) {
+            S7::new_property(
+                S7::new_union(S3_waiver, NULL, S7::class_character),
+                validator = function(value) {
+                    if (!is_waiver(value) && !is.null(value) &&
+                        length(value) != 1L) {
+                        return("must be a single character string")
+                    }
+                },
+                default = quote(waiver())
+            )
+        }
+    )
+)
+
+#' @importFrom S7 prop prop<-
+S7::method(init_object, layout_title) <- function(input) {
+    prop(input, "title", check = FALSE) <- prop(input, "title") %|w|% NULL
+    prop(input, "subtitle", check = FALSE) <- prop(input, "subtitle") %|w|% NULL
+    prop(input, "caption", check = FALSE) <- prop(input, "caption") %|w|% NULL
+    input
+}
+
+#' @importFrom ggplot2 is_waiver
+#' @importFrom S7 props
+local(
+    S7::method(`+`, list(layout_title, layout_title)) <-
+        function(e1, e2) {
+            fields <- props(e2)
+            fields <- fields[
+                !vapply(fields, is_waiver, logical(1L), USE.NAMES = FALSE)
+            ]
+            if (length(fields)) props(e1) <- fields
+            e1
+        }
+)
+
+##########################################################
 #' Add patch titles to plot borders
 #'
 #' This function extends ggplot2's title functionality, allowing you to add
@@ -24,48 +82,90 @@
 #' @examples
 #' ggplot(mtcars) +
 #'     geom_point(aes(mpg, disp)) +
-#'     patch_titles(
+#'     patch_title(
 #'         top = "I'm top patch title",
 #'         left = "I'm left patch title",
 #'         bottom = "I'm bottom patch title",
 #'         right = "I'm right patch title"
 #'     )
+#' @importFrom ggplot2 waiver is_waiver
 #' @export
-#' @importFrom ggplot2 waiver
-patch_titles <- function(top = waiver(), left = waiver(), bottom = waiver(),
-                         right = waiver()) {
-    structure(
-        list(top = top, left = left, bottom = bottom, right = right),
-        class = "ggalign_patch_labels"
+patch_title <- S7::new_class(
+    "patch_title",
+    properties = lapply(
+        rlang::set_names(c("top", "left", "bottom", "right")),
+        function(position) {
+            S7::new_property(
+                S7::new_union(S3_waiver, NULL, S7::class_character),
+                validator = function(value) {
+                    if (!is_waiver(value) && !is.null(value) &&
+                        length(value) != 1L) {
+                        return("must be a single character string")
+                    }
+                },
+                default = quote(waiver())
+            )
+        }
     )
+)
+
+#' @export
+#' @usage NULL
+#' @rdname patch_title
+patch_titles <- function(...) {
+    lifecycle::deprecate_soft(
+        "1.2.0",
+        "patch_titles()",
+        details = "Please use `patch_title()` instead"
+    )
+    patch_title(...)
 }
 
+#' @importFrom ggplot2 is_waiver
+#' @importFrom S7 props
+local(
+    S7::method(`+`, list(patch_title, patch_title)) <-
+        function(e1, e2) {
+            fields <- props(e2)
+            fields <- fields[
+                !vapply(fields, is_waiver, logical(1L), USE.NAMES = FALSE)
+            ]
+            if (length(fields)) props(e1) <- fields
+            e1
+        }
+)
+
 #' @importFrom ggplot2 find_panel zeroGrob
-#' @importFrom ggplot2 calc_element element_grob merge_element
+#' @importFrom ggplot2 calc_element element_grob merge_element is_theme_element
 #' @importFrom rlang arg_match0
 #' @importFrom grid grobName
-setup_patch_titles <- function(table, patch_titles, theme) {
+setup_patch_title <- function(table, patch_title, theme) {
+    patch_title <- patch_title %||% patch_title()
     old_text <- calc_element("plot.title", theme)
     # always justification by center for patch title
     old_text$hjust <- 0.5
-    if (is.null(text <- .subset2(theme, "plot.patch_title"))) {
+    if (is.null(text <- theme$plot.patch_title)) {
         text <- old_text
-    } else if (inherits(text, "element_text")) {
+    } else if (is_theme_element(text, "text")) {
         text <- merge_element(text, old_text)
     } else {
-        cli_abort(paste(
-            "Theme element {.var plot.patch_title} must be a",
-            "{.cls element_text}."
-        ), call = quote(theme()))
+        cli_abort(
+            paste(
+                "Theme element {.var plot.patch_title} must be a",
+                "{.cls element_text}."
+            ),
+            call = quote(theme())
+        )
     }
     # inherit from plot.title.position, default use "panel"
-    position <- .subset2(theme, "plot.patch_title.position") %||%
-        .subset2(theme, "plot.title.position") %||% "panel"
+    position <- theme$plot.patch_title.position %||%
+        theme$plot.title.position %||% "panel"
+
     for (border in .TLBR) {
+        title <- prop(patch_title, border) %|w|% NULL
         panel_pos <- find_panel(table)
-        patch_title <- .subset2(patch_titles, border)
         name <- paste("plot.patch_title", border, sep = ".")
-        if (is.null(patch_title)) {
+        if (is.null(title)) {
             title <- zeroGrob()
         } else {
             # set the default angle
@@ -76,26 +176,27 @@ setup_patch_titles <- function(table, patch_titles, theme) {
                 right = -90L
             )
             # we merge the element with `plot.patch_title`
-            if (is.null(el <- .subset2(theme, name))) {
+            if (is.null(el <- theme[[name]])) {
                 el <- text
-            } else if (inherits(el, "element_text")) {
+            } else if (is_theme_element(el, "text")) {
                 el <- merge_element(el, text)
             } else {
-                cli_abort(paste(
-                    "Theme element {.var {name}} must have",
-                    "class {.cls element_text}."
-                ), call = quote(theme()))
+                cli_abort(
+                    paste(
+                        "Theme element {.var {name}} must have",
+                        "class {.cls element_text}."
+                    ),
+                    call = quote(theme())
+                )
             }
             # render the patch title grob
-            title <- element_grob(el, patch_title,
-                margin_y = TRUE, margin_x = TRUE
-            )
+            title <- element_grob(el, title, margin_y = TRUE, margin_x = TRUE)
             title$name <- grobName(title, name)
         }
 
         name <- paste("plot.patch_title.position", border, sep = ".")
         pos <- arg_match0(
-            .subset2(theme, name) %||% position,
+            theme[[name]] %||% position,
             c("panel", "plot"),
             arg_nm = name,
             error_call = quote(theme())
@@ -169,15 +270,13 @@ setup_patch_titles <- function(table, patch_titles, theme) {
     table
 }
 
-#' @importFrom ggplot2 ggplot_add
-#' @export
-ggplot_add.ggalign_patch_labels <- function(object, plot, object_name, ...) {
-    for (nm in names(object)) {
-        if (is.waive(.subset2(object, nm))) next
-        plot$ggalign_patch_labels[nm] <- list(.subset2(object, nm))
+#' @importFrom ggplot2 update_ggplot is_waiver
+S7::method(update_ggplot, list(patch_title, ggplot2::class_ggplot)) <-
+    function(object, plot, objectname, ...) {
+        plot$ggalign_patch_title <- (plot$ggalign_patch_title %||%
+            patch_title()) + object
+        if (!inherits(plot, "patch_ggplot")) {
+            plot <- add_class(plot, "patch_ggplot")
+        }
+        plot
     }
-    if (!inherits(plot, "patch_ggplot")) {
-        plot <- add_class(plot, "patch_ggplot")
-    }
-    plot
-}
