@@ -3,24 +3,12 @@
 #' The `ggwrap()` function allows non-ggplot2 elements to be converted into a
 #' compliant representation for use with [`align_plots()`]. This is useful for
 #' adding any graphics that can be converted into a [`grob`][grid::grob] with
-#' the [`patch()`] method.
+#' the [`as_grob()`] method.
 #'
-#' @param plot Any graphic that can be converted into a [`grob`][grid::grob]
-#' using [`patch()`].
-#' @param ... Additional arguments passed to the [`patch()`] method.
-#' @param align A string specifying the area to place the plot: `"full"` for the
-#' full area, `"plot"` for the full plotting area (including the axis label), or
-#' `"panel"` for only the actual area where data is drawn.
-#' @param clip A single boolean value indicating whether the grob should be
-#' clipped if they expand outside their designated area.
-#' @param on_top A single boolean value indicates whether the graphic plot
-#' should be put frontmost. Note: the graphic plot will always put above the
-#' background.
-#' @param vp A [`viewport`][grid::viewport] object, you can use this to define
-#' the plot area.
+#' @inheritParams inset
 #' @return A `wrapped_plot` object that can be directly placed into
 #' [`align_plots()`].
-#' @inherit patch seealso
+#' @inherit as_grob seealso
 #' @examples
 #' library(grid)
 #' ggwrap(rectGrob(gp = gpar(fill = "goldenrod")), align = "full") +
@@ -37,7 +25,6 @@
 #' ))
 #'
 #' @importFrom ggplot2 theme element_blank ggplot
-#' @importFrom grid is.grob
 #' @export
 ggwrap <- function(plot, ..., align = "panel", on_top = FALSE,
                    clip = TRUE, vp = NULL) {
@@ -46,92 +33,93 @@ ggwrap <- function(plot, ..., align = "panel", on_top = FALSE,
             plot.background = element_blank(),
             panel.background = element_blank()
         )
-    inset <- make_inset(
-        plot = plot, ..., align = align, on_top = on_top,
+    patch_inset <- inset(
+        plot = plot, ...,
+        align = align, on_top = on_top,
         clip = clip, vp = vp
     )
-    make_wrap(patch, inset)
+    make_wrap(patch, patch_inset)
 }
 
-make_wrap <- function(patch, inset) UseMethod("make_wrap")
+make_wrap <- function(patch, patch_inset) UseMethod("make_wrap")
 
-make_wrapped_plot <- function(patch, inset) {
-    if (.subset2(inset, "on_top")) {
-        patch$ggalign_wrapped_insets_above <- c(
-            patch$ggalign_wrapped_insets_above, list(inset)
+make_wrapped_plot <- function(patch, patch_inset) {
+    if (prop(patch_inset, "on_top")) {
+        attr(patch, "ggalign_wrapped_insets_above") <- c(
+            attr(patch, "ggalign_wrapped_insets_above", exact = TRUE),
+            list(patch_inset)
         )
     } else {
-        patch$ggalign_wrapped_insets_under <- c(
-            patch$ggalign_wrapped_insets_under, list(inset)
+        attr(patch, "ggalign_wrapped_insets_under") <- c(
+            attr(patch, "ggalign_wrapped_insets_under", exact = TRUE),
+            list(patch_inset)
         )
     }
     add_class(patch, "wrapped_plot")
 }
 
-#' @export
-make_wrap.ggplot <- function(patch, inset) {
+S7::method(make_wrap, ggplot2::class_ggplot) <- function(patch, patch_inset) {
     patch <- add_class(patch, "patch_ggplot")
-    make_wrap(patch, inset)
+    make_wrap(patch, patch_inset)
 }
 
 #' @export
 make_wrap.patch_ggplot <- make_wrapped_plot
 
-#' @export
-`make_wrap.ggalign::AlignPatches` <- make_wrapped_plot
+S7::method(make_wrap, alignpatches) <- make_wrapped_plot
 
 #################################################
 #' @importFrom ggplot2 ggproto ggproto_parent
 #' @export
-alignpatch.wrapped_plot <- function(x) {
+patch.wrapped_plot <- function(x) {
+    under <- attr(x, "ggalign_wrapped_insets_under", exact = TRUE)
+    attr(x, "ggalign_wrapped_insets_under") <- NULL
+    above <- attr(x, "ggalign_wrapped_insets_above", exact = TRUE)
+    attr(x, "ggalign_wrapped_insets_above") <- NULL
     Parent <- NextMethod()
     ggproto(
         "PatchWrapped", Parent,
-        ggalign_wrapped_insets_under = x$ggalign_wrapped_insets_under,
-        ggalign_wrapped_insets_above = x$ggalign_wrapped_insets_above,
-        patch_gtable = function(self, theme = NULL, guides = NULL,
-                                tagger = NULL) {
-            ans <- ggproto_parent(Parent, self)$patch_gtable(
-                theme = theme, guides = guides, tagger = tagger
-            )
-            ans <- add_wrapped_insets(
-                ans, self$ggalign_wrapped_insets_under, FALSE
-            )
-            add_wrapped_insets(ans, self$ggalign_wrapped_insets_above, TRUE)
+        under = under,
+        above = above,
+        gtable = function(self, theme = NULL, guides = NULL,
+                          tagger = NULL) {
+            ans <- ggproto_parent(Parent, self)$gtable(theme, guides, tagger)
+            ans <- add_wrapped_insets(ans, self$under, FALSE)
+            add_wrapped_insets(ans, self$above, TRUE)
         }
     )
 }
 
 # For wrapped plot -------------------
 #' @export
-alignpatch.grob <- function(x) alignpatch(ggwrap(x))
+patch.grob <- function(x) patch(ggwrap(x))
 
 #' @export
-alignpatch.gList <- alignpatch.grob
+patch.gList <- patch.grob
 
 #' @export
-alignpatch.formula <- alignpatch.grob
+patch.formula <- patch.grob
 
 #' @export
-alignpatch.function <- alignpatch.grob
+patch.function <- patch.grob
 
 #' @export
-alignpatch.recordedplot <- alignpatch.grob
+patch.recordedplot <- patch.grob
 
 #' @export
-alignpatch.trellis <- alignpatch.grob
+patch.trellis <- patch.grob
 
 #' @export
-alignpatch.Heatmap <- function(x) alignpatch(ggwrap(x, align = "full"))
+patch.Heatmap <- function(x) patch(ggwrap(x, align = "full"))
 
 #' @export
-alignpatch.HeatmapList <- alignpatch.Heatmap
+patch.HeatmapList <- patch.Heatmap
 
 #' @export
-alignpatch.HeatmapAnnotation <- alignpatch.Heatmap
+patch.HeatmapAnnotation <- patch.Heatmap
 
 #' @export
-alignpatch.pheatmap <- function(x) alignpatch(ggwrap(x, align = "full"))
+patch.pheatmap <- function(x) patch(ggwrap(x, align = "full"))
 
 ################################################## 3
 add_wrapped_insets <- function(gt, insets, on_top) {
@@ -142,12 +130,15 @@ add_wrapped_insets <- function(gt, insets, on_top) {
     gt
 }
 
+#' @importFrom S7 prop
+#' @importFrom grid editGrob
 #' @importFrom gtable gtable is.gtable gtable_add_grob
-add_wrapped_inset <- function(gt, inset, on_top, i) {
-    align <- .subset2(inset, "align")
-    clip <- .subset2(inset, "clip")
+add_wrapped_inset <- function(gt, patch_inset, on_top, i) {
+    align <- prop(patch_inset, "align")
+    clip <- prop(patch_inset, "clip")
     layout <- .subset2(gt, "layout")
-    grob <- .subset2(inset, "grob")
+    grob <- prop(patch_inset, "grob")
+    if (!is.null(vp <- prop(patch_inset, "vp"))) grob <- editGrob(grob, vp = vp)
     if (on_top) {
         z <- Inf
     } else {
