@@ -78,7 +78,7 @@ align_dendro <- function(mapping = aes(), ...,
         )
     }
     assert_active(active)
-    active <- active_update(active(use = TRUE), active)
+    active <- active(use = TRUE) + active
     .align_hclust(
         align = AlignDendro,
         distance = distance,
