@@ -7,7 +7,7 @@
 #' @inheritParams ggplot2::layer
 #' @inheritParams ggplot2::geom_polygon
 #' @inheritParams ggplot2::geom_path
-#' @eval rd_gg_aesthetics("geom", "rect3d")
+#' @aesthetics GeomRect3d
 #' @examples
 #' set.seed(123)
 #' small_mat <- matrix(rnorm(81), nrow = 9)
@@ -53,7 +53,7 @@ geom_rect3d <- function(mapping = NULL, data = NULL, stat = "identity",
     )
 }
 
-#' @importFrom ggplot2 ggproto fill_alpha
+#' @importFrom ggplot2 ggproto fill_alpha gg_par
 GeomRect3d <- ggproto(
     "GeomRect3d",
     ggplot2::GeomRect,
@@ -91,7 +91,7 @@ GeomRect3d <- ggproto(
             y = coords$y,
             id = coords$polygon_id,
             default.units = "native",
-            gp = gpar(
+            gp = gg_par(
                 col = data$colour,
                 fill = fill_alpha(data$fill, data$alpha),
                 lwd = data$linewidth,
@@ -158,7 +158,7 @@ setup_3d_data <- function(data) {
     )
 }
 
-#' @eval rd_gg_aesthetics("geom", "tile3d")
+#' @aesthetics GeomTile3d
 #' @importFrom rlang list2
 #' @export
 #' @rdname geom_rect3d
@@ -174,7 +174,7 @@ geom_tile3d <- function(mapping = NULL, data = NULL, stat = "identity",
         position = position,
         show.legend = show.legend,
         inherit.aes = inherit.aes,
-        params = list(
+        params = list2(
             lineend = lineend,
             linejoin = linejoin,
             linemitre = linemitre,
