@@ -78,9 +78,11 @@ setup_discrete_limits <- function(axis, domain, n_panels) {
     }
 }
 
-#' @importFrom ggplot2 ggplot_add ggproto ggproto_parent
-#' @export
-ggplot_add.layout_align <- function(object, plot, object_name, ...) {
+#' @importFrom ggplot2 update_ggplot ggproto ggproto_parent
+S7::method(
+    update_ggplot,
+    list(S7::new_S3_class("layout_align"), ggplot2::class_ggplot)
+) <- function(object, plot, object_name, ...) {
     x_domain <- .subset2(object, "x")
     y_domain <- .subset2(object, "y")
     if (is.null(x_domain) && is.null(y_domain)) {
@@ -221,8 +223,8 @@ align_discrete_scales <- function(axis, scales, domain, labels, n_panels,
         # https://github.com/tidyverse/ggplot2/blob/7fb4c382f9ea332844d469663a8047355a88dd7a/R/scale-.R#L927
         # setup breaks and labels --------------------
         if (is.null(data_labels) &&
-            is.waive(scale$labels) &&
-            is.waive(scale$breaks)) {
+            is_waiver(scale$labels) &&
+            is_waiver(scale$breaks)) {
             # special case for data have no labels
             # By default we also remove the breaks
             scale$breaks <- NULL
@@ -274,7 +276,7 @@ get_discrete_breaks <- function(scale, pindex, dindex, labels) {
     if (is.null(breaks)) {
         return(NULL)
     }
-    if (is.waive(breaks)) {
+    if (is_waiver(breaks)) {
         if (scale$is_discrete() &&
             !is.null(labels) &&
             !is.null(scale$range$range) &&
@@ -360,7 +362,7 @@ get_discrete_labels <- function(scale, breaks, pindex, dindex, labels) {
     } else {
         user_breaks <- labels
     }
-    if (is.waive(scale_labels)) { # By default, use the breaks
+    if (is_waiver(scale_labels)) { # By default, use the breaks
         user_breaks
     } else if (is.function(scale_labels)) {
         scale_labels(user_breaks)
