@@ -67,15 +67,15 @@ S7::method(layout_add, list(ChainLayout, CraftBox)) <-
 
 #' @include layout-.R
 #' @include layout-operator.R
-S7::method(layout_add, list(ChainLayout, S3_class_ggplot)) <-
+S7::method(layout_add, list(ChainLayout, ggplot2::class_ggplot)) <-
     function(layout, object, objectname) {
         layout_add(layout, ggfree(data = object), objectname)
     }
 
 #' @include layout-.R
-S7::method(layout_add, list(ChainLayout, S3_layout_title)) <-
+S7::method(layout_add, list(ChainLayout, layout_title)) <-
     function(layout, object, objectname) {
-        layout@titles <- layout_title_update(layout@titles, object)
+        layout@titles <- layout@titles + object
         layout
     }
 
@@ -166,7 +166,7 @@ chain_add_box <- function(layout, box, active, object_name) {
 }
 
 switch_chain_plot <- function(layout, what, call = caller_call()) {
-    if (!is.waive(what)) {
+    if (!is_waiver(what)) {
         if (!is.na(what)) {
             what <- vec_as_location2(
                 what,
@@ -186,7 +186,7 @@ switch_chain_plot <- function(layout, what, call = caller_call()) {
 #' @include layout-.R
 #' @include layout-operator.R
 #' @include layout-quad-scope.R
-S7::method(layout_add, list(StackLayout, QuadScope)) <-
+S7::method(layout_add, list(StackLayout, quad_scope)) <-
     S7::method(
         layout_add,
         list(StackLayout, S7::new_S3_class("quad_active"))
@@ -214,7 +214,7 @@ S7::method(layout_add, list(StackLayout, QuadScope)) <-
         layout
     }
 
-S7::method(layout_add, list(CircleLayout, QuadScope)) <-
+S7::method(layout_add, list(CircleLayout, quad_scope)) <-
     S7::method(layout_add, list(CircleLayout, QuadLayout)) <-
     S7::method(
         layout_add,
@@ -337,7 +337,7 @@ S7::method(layout_add, list(StackLayout, QuadLayout)) <-
                 c("vertical", "horizontal"), direction
             ))
             allow_null <- !is_discrete_domain(extra_domain)
-            if (is.waive(quad_data) || is.function(quad_data)) {
+            if (is_waiver(quad_data) || is.function(quad_data)) {
                 # check if we should initialize the `quad_layout()` data
                 if (is.null(stack_data <- layout@data)) {
                     if (allow_null) {
@@ -356,7 +356,7 @@ S7::method(layout_add, list(StackLayout, QuadLayout)) <-
                     }
                 } else {
                     data <- stack_data # should be a data frame
-                    if (is.waive(quad_data)) { # inherit from the stack layout
+                    if (is_waiver(quad_data)) { # inherit from the stack layout
                         if (!allow_null) { # we need a matrix
                             cli_abort(c(
                                 sprintf(
@@ -418,7 +418,7 @@ S7::method(layout_add, list(StackLayout, QuadLayout)) <-
         } else if (is_discrete_domain(stack_domain)) {
             # both `quad_layout()` and `stack_layout()` will align discrete
             # variables
-            if (is.waive(quad_data) || is.function(quad_data)) {
+            if (is_waiver(quad_data) || is.function(quad_data)) {
                 if (is.null(stack_data <- layout@data)) {
                     cli_abort(c(
                         sprintf(
@@ -504,7 +504,7 @@ S7::method(layout_add, list(StackLayout, QuadLayout)) <-
 #' @include layout-operator.R
 S7::method(layout_add, list(CircleLayout, S7::new_S3_class("circle_switch"))) <-
     function(layout, object, objectname) {
-        if (!is.waive(radial <- .subset2(object, "radial"))) {
+        if (!is_waiver(radial <- .subset2(object, "radial"))) {
             layout@radial <- radial
         }
         if (!is.null(direction <- .subset2(object, "direction"))) {
@@ -571,22 +571,21 @@ S7::method(layout_subtract, list(ChainLayout, Scheme)) <-
 #' @include layout-.R
 #' @include layout-operator.R
 #' @include layout-quad-scope.R
-S7::method(layout_subtract, list(StackLayout, QuadScope)) <-
+S7::method(layout_subtract, list(StackLayout, quad_scope)) <-
     function(layout, object, objectname) {
         if (is.na(current <- layout@current) ||
             is_craftbox(box <- .subset2(layout@box_list, current))) {
             inner <- prop(object, "object")
-            inner_name <- prop(object, "object_name")
 
             # subtract set at layout level, if it is a Scheme
             if (S7_inherits(inner, Scheme)) {
-                layout <- update_layout_schemes(inner, layout, inner_name)
+                layout <- update_layout_schemes(inner, layout, objectname)
             }
 
             # otherwise, we apply the object to all plots in the stack layout
             layout@box_list <- lapply(layout@box_list, function(box) {
                 if (is_craftbox(box)) {
-                    box <- chain_box_add(box, inner, inner_name, force = FALSE)
+                    box <- chain_box_add(box, inner, objectname, force = FALSE)
                 } else {
                     # we respect the context setting
                     box <- layout_subtract(box, object, objectname)
@@ -605,19 +604,18 @@ S7::method(layout_subtract, list(StackLayout, QuadScope)) <-
 #' @include layout-.R
 #' @include layout-operator.R
 #' @include layout-quad-scope.R
-S7::method(layout_and_add, list(ChainLayout, QuadScope)) <-
+S7::method(layout_propagate, list(ChainLayout, quad_scope)) <-
     function(layout, object, objectname) {
-        object_name <- prop(object, "object_name")
         object <- prop(object, "object")
-        layout_and_add(layout, object, object_name)
+        layout_propagate(layout, object, objectname)
     }
 
-chain_and_add <- function(layout, object, objectname) {
+chain_propagate <- function(layout, object, objectname) {
     layout@box_list <- lapply(layout@box_list, function(box) {
         if (is_craftbox(box)) {
             box <- chain_box_add(box, object, objectname, force = FALSE)
         } else {
-            box <- layout_and_add(box, object, objectname)
+            box <- layout_propagate(box, object, objectname)
         }
         box
     })
@@ -626,15 +624,14 @@ chain_and_add <- function(layout, object, objectname) {
 
 #' @include layout-.R
 #' @include layout-operator.R
-S7::method(layout_and_add, list(ChainLayout, S7::class_any)) <-
-    chain_and_add
+S7::method(layout_propagate, list(ChainLayout, S7::class_any)) <-
+    chain_propagate
 
-#' @importFrom S7 super
 #' @include layout-.R
 #' @include layout-operator.R
-S7::method(layout_and_add, list(ChainLayout, S3_class_theme)) <-
+S7::method(layout_propagate, list(ChainLayout, S3_class_theme)) <-
     function(layout, object, objectname) {
-        ans <- chain_and_add(layout, object, objectname)
+        ans <- chain_propagate(layout, object, objectname)
         # to align with `patchwork`, we also modify the layout theme
         # when using `&` to add the theme object.
         ans@theme <- ggfun("add_theme")(ans@theme, object)
