@@ -53,11 +53,8 @@ link_draw <- function(.draw, ...) {
 #' @seealso [`link_draw()`]
 #' @export
 .link_draw <- function(.draw, ...) {
-    if (override_call(call <- caller_call())) {
-        call <- current_call()
-    }
     if (!is.function(draw <- allow_lambda(.draw))) {
-        cli_abort("{.arg .draw} must be a function", call = call)
+        cli_abort("{.arg .draw} must be a function")
     }
     args <- names(formals(draw))
     if (length(args) < 1L && args != "...") {
@@ -95,7 +92,7 @@ link_line <- function(..., .element = NULL) {
         type = "line",
         allow_null = TRUE
     )
-    default <- calc_element("ggalign.line", complete_theme(theme_get()))
+    default <- calc_element("line", complete_theme(theme_get()))
     if (is.null(.element)) {
         .element <- default
     } else {
@@ -157,7 +154,7 @@ link_tetragon <- function(..., .element = NULL) {
         type = "polygon",
         allow_null = TRUE
     )
-    default <- calc_element("ggalign.polygon", complete_theme(theme_get()))
+    default <- calc_element("polygon", complete_theme(theme_get()))
     if (is.null(.element)) {
         .element <- default
     } else {
