@@ -62,14 +62,15 @@ Schemes <- S7::new_class("Schemes",
 )
 
 #' @importFrom utils str
-#' @importFrom S7 props
+#' @importFrom S7 prop
 local(S7::method(str, Schemes) <- function(object, ..., nest.lev = 0) {
     cat(if (nest.lev > 0) " ")
     cat(paste0("<", main_class(object), ">\n"))
-    str_nest(.subset(props(object), "value"), "@", ..., nest.lev = nest.lev)
+    str_nest(list(prop(object, "value")), "@", ..., nest.lev = nest.lev)
 })
 
 #' @importFrom rlang list2
+#' @importFrom S7 prop prop<-
 schemes_set <- function(schemes, ..., check = TRUE) {
     entries <- prop(schemes, "entries")
     for (entry in list2(...)) {
@@ -86,7 +87,7 @@ schemes_get <- function(schemes, scheme) {
 
 #' @importFrom ggplot2 theme waiver
 default_schemes <- function(data = NULL, th = theme()) {
-    if (!is.waive(data)) data <- NULL
+    if (!is_waiver(data)) data <- NULL
     Schemes(
         scheme_data(data),
         scheme_theme(th),
@@ -201,7 +202,7 @@ S7::method(scheme_update, list(Schemes, Scheme)) <- function(e1, e2, e2name) {
         cli_abort("{.fn scheme_update} method must return a {.cls scheme}")
     }
     entries[[prop(new_entry, "key")]] <- new_entry
-    attr(e1, "value") <- entries
+    prop(e1, "value", check = FALSE) <- entries
     e1
 }
 
@@ -292,22 +293,21 @@ plot_add_scheme <- S7::new_generic("plot_add_scheme", c("plot", "scheme"))
 
 S7::method(plot_add_scheme, list(S7::class_any, Schemes)) <-
     function(plot, scheme, ...) {
-        entries <- prop(scheme, "entries")
-        for (entry in entries) {
+        for (entry in prop(scheme, "entries")) {
             plot <- plot_add_scheme(plot, entry, ...)
         }
         plot
     }
 
 #' @include utils-ggplot.R
-S7::method(plot_add_scheme, list(S3_class_ggplot, Scheme)) <-
+S7::method(plot_add_scheme, list(ggplot2::class_ggplot, Scheme)) <-
     function(plot, scheme, ...) {
         cli_abort(
             "No {.fn plot_add_scheme} method for {.obj_type_friendly {plot}} and {.obj_type_friendly {scheme}}"
         )
     }
 
-update_layout_schemes <- function(object, layout, object_name) {
-    layout@schemes <- scheme_update(layout@schemes, object, object_name)
+update_layout_schemes <- function(object, layout, objectname) {
+    layout@schemes <- scheme_update(layout@schemes, object, objectname)
     layout
 }
