@@ -38,7 +38,7 @@ scheme_data <- S7::new_class(
         data = S7::new_property(
             S7::class_any,
             validator = function(value) {
-                if (is.waive(value) || is.null(value) || is.function(value)) {
+                if (is_waiver(value) || is.null(value) || is.function(value)) {
                     return(NULL)
                 }
                 sprintf("must be a function, `NULL`, or {.fn waiver}")
@@ -64,7 +64,7 @@ scheme_data <- S7::new_class(
 #' @importFrom S7 prop prop<-
 S7::method(scheme_inherit, list(scheme_data, scheme_data)) <- function(e1, e2) {
     if (is.null(scheme_data <- prop(e2, "data"))) return(e2) # styler: off
-    if (is.waive(scheme_data)) return(e1) # inherit from parent; styler: off
+    if (is_waiver(scheme_data)) return(e1) # inherit from parent; styler: off
     if (!is.function(p_function <- prop(e1, "data"))) {
         return(e2)
     }
@@ -81,13 +81,13 @@ S7::method(scheme_inherit, list(scheme_data, scheme_data)) <- function(e1, e2) {
 }
 
 #' @importFrom S7 prop
-S7::method(plot_add_scheme, list(S3_class_ggplot, scheme_data)) <-
+S7::method(plot_add_scheme, list(ggplot2::class_ggplot, scheme_data)) <-
     function(plot, scheme, ...) {
         if (!is.null(scheme_data <- prop(scheme, "data") %|w|% NULL) &&
             !is.null(raw_data <- plot$data)) {
             # To be compatible with ggplot2, it must be a data frame
             if (!is.null(data <- scheme_data(raw_data)) &&
-                !is.waive(data) &&
+                !is_waiver(data) &&
                 !is.data.frame(data)) {
                 cli_abort("{.fn scheme_data} must return a {.cls data.frame}")
             }
