@@ -9,14 +9,6 @@ recycle_each <- function(x, len) {
     (x - 1L) %/% len + 1L
 }
 
-#' @importFrom utils modifyList
-update_non_waive <- function(old, new, keep_null = TRUE) {
-    modifyList(old,
-        new[!vapply(new, is.waive, logical(1L), USE.NAMES = FALSE)],
-        keep.null = keep_null
-    )
-}
-
 is_s3 <- function(x) is.object(x) && !isS4(x) && !inherits(x, "R6")
 
 #' @importFrom rlang names2
@@ -73,7 +65,7 @@ fn_body_append <- function(fn, ..., ans = FALSE) {
 # `foo.default`.
 #' @importFrom utils getS3method
 #' @importFrom methods extends
-has_method <- function(x, f, inherit = TRUE, default = inherit) {
+has_s3_method <- function(x, f, inherit = TRUE, default = inherit) {
     x_class <- class(x)
     if (inherit) {
         if (isS4(x)) x_class <- extends(x_class)
@@ -239,8 +231,36 @@ fct_rev <- function(x) {
 
 reverse_trans <- function(x) sum(range(x, na.rm = TRUE)) - x
 
-fclass <- function(x) .subset(class(x), 1L)
+main_class <- function(x) .subset(class(x), 1L)
 
 is_scalar <- function(x) length(x) == 1L
 
 is_scalar_numeric <- function(x) length(x) == 1L && is.numeric(x)
+
+str_nest <- function(
+    object,
+    prefix,
+    ...,
+    nest.lev = 0,
+    indent.str = paste(rep.int(" ", max(0, nest.lev + 1)), collapse = "..")) {
+    names <- format(names(object))
+
+    for (i in seq_along(object)) {
+        cat(indent.str, prefix, " ", names[[i]], ":", sep = "")
+
+        xi <- object[[i]]
+        if (is.function(xi)) {
+            str_function(xi, nest.lev = nest.lev + 1)
+        } else {
+            str(xi, ..., nest.lev = nest.lev + 1)
+        }
+    }
+}
+
+str_function <- function(object, ..., nest.lev = 0) {
+    attr(object, "srcref") <- NULL
+    if (identical(class(object), "function")) {
+        cat(" ")
+    }
+    str(object, ..., nest.lev = nest.lev)
+}
