@@ -75,17 +75,17 @@ test_that("The grid can be controlled", {
 
     expect_doppelganger("patch titles", {
         align_plots(
-            p1 + patch_titles(top = "I'm top patch title"),
-            p2 + patch_titles(left = "I'm left patch title"),
-            p3 + patch_titles(bottom = "I'm bottom patch title"),
-            p4 + patch_titles(right = "I'm right patch title")
+            p1 + patch_title(top = "I'm top patch title"),
+            p2 + patch_title(left = "I'm left patch title"),
+            p3 + patch_title(bottom = "I'm bottom patch title"),
+            p4 + patch_title(right = "I'm right patch title")
         )
     })
     expect_doppelganger("patch titles theme", {
         align_plots(
-            p1 + patch_titles(top = "I'm top patch title") +
+            p1 + patch_title(top = "I'm top patch title") +
                 theme(plot.patch_title.top = element_text(face = "bold")),
-            p2 + patch_titles(left = "I'm left patch title") +
+            p2 + patch_title(left = "I'm left patch title") +
                 theme(plot.patch_title.left = element_text(face = "bold"))
         )
     })
@@ -119,6 +119,29 @@ test_that("The grid can be controlled", {
     })
 })
 
+test_that("strip handling works well", {
+    p1 <- ggplot(mtcars) +
+        geom_point(aes(mpg, disp))
+    p2 <- ggplot(mtcars) +
+        geom_boxplot(aes(gear, disp, group = gear))
+    p3 <- ggplot(mtcars) +
+        geom_bar(aes(gear)) +
+        facet_wrap(~cyl)
+    expect_doppelganger("align_plots() with mixed faceted and single plots", {
+        align_plots(p1, align_plots(p3, p2, nrow = 1L), ncol = 1)
+    })
+
+    p0 <- ggplot(mpg, aes(displ, hwy)) +
+        geom_point() +
+        facet_wrap(~"foo", strip.position = "bottom") +
+        theme(strip.placement = "inside", strip.text = element_text(size = 20))
+    p1 <- p0 + theme(strip.placement = "outside")
+    expect_doppelganger(
+        "alignpatches() with inside vs outside strip placement",
+        alignpatches(p0, p1)
+    )
+})
+
 test_that("accept patchwork", {
     testthat::skip_if_not_installed("patchwork")
     p1 <- ggplot(mtcars) +
@@ -281,8 +304,7 @@ test_that("Fixed aspect plots behave", {
         align_plots(
             p_l1 + theme(legend.justification = "left", aspect.ratio = 1),
             p_l2 + theme(legend.justification = "left", aspect.ratio = 1),
-            ncol = 1L,
-            widths = unit(c(1, 3, NA), c("null", "cm", "null"))
+            ncol = 1L
         )
     })
 })
