@@ -3,23 +3,17 @@ testthat::test_that("`stack_align` works well", {
     x <- stack_alignh(1:10)
     expect_true(is.matrix(x@data))
     expect_identical(ncol(x@data), 1L)
-    expect_identical(x@design, discrete_design(nobs = 10L))
-    # str method works well
-    expect_no_error(str(x))
+    expect_identical(x@domain, DiscreteDomain(nobs = 10L))
 
     x <- stack_alignh(letters)
     expect_true(is.matrix(x@data))
     expect_identical(ncol(x@data), 1L)
-    expect_identical(x@design, discrete_design(nobs = length(letters)))
-    # str method works well
-    expect_no_error(str(x))
+    expect_identical(x@domain, DiscreteDomain(nobs = length(letters)))
 
     # stack with no data
     x <- stack_alignh()
-    expect_s3_class(x@sizes, "unit")
-    expect_identical(x@design, discrete_design())
-    # str method works well
-    expect_no_error(str(x))
+    expect_s7_class(x@sizes, GridUnit)
+    expect_identical(x@domain, DiscreteDomain())
 })
 
 testthat::test_that("`stack_free` works well", {
@@ -27,23 +21,29 @@ testthat::test_that("`stack_free` works well", {
     x <- stack_freeh(1:10)
     expect_true(is.data.frame(x@data))
     expect_identical(names(x@data), "value")
-    expect_identical(x@design, NULL)
-    # str method works well
-    expect_no_error(str(x))
+    expect_identical(x@domain, NULL)
 
     x <- stack_freeh(letters)
     expect_true(is.data.frame(x@data))
     expect_identical(names(x@data), "value")
-    expect_identical(x@design, NULL)
-    # str method works well
-    expect_no_error(str(x))
+    expect_identical(x@domain, NULL)
 
     # stack with no data
     x <- stack_freeh()
-    expect_s3_class(x@sizes, "unit")
-    expect_identical(x@design, NULL)
-    # str method works well
-    expect_no_error(str(x))
+    expect_s7_class(x@sizes, GridUnit)
+    expect_identical(x@domain, NULL)
+})
+
+testthat::test_that("`stack_genomic()` works well", {
+    # atomic was converted to one-column data frame
+    expect_doppelganger("stack_genomicv", {
+        stack_genomicv("hg38") +
+            plot_ideogram(size = 20, seqnames = 0)
+    })
+    expect_doppelganger("stack_genomich", {
+        stack_genomich("hg38") +
+            plot_ideogram(size = 20, seqnames = 0)
+    })
 })
 
 testthat::test_that("`stack_align` add `align-` object builds well", {
@@ -122,13 +122,13 @@ testthat::test_that("`stack_align` add `quad_layout()` object builds well", {
     })
 })
 
-testthat::test_that("add `with_quad()` works as expected", {
+testthat::test_that("add `quad_scope()` works as expected", {
     set.seed(1L)
     small_mat <- matrix(rnorm(72), nrow = 8)
     rownames(small_mat) <- paste0("row", seq_len(nrow(small_mat)))
     colnames(small_mat) <- paste0("column", seq_len(ncol(small_mat)))
     expect_doppelganger(
-        "subtract_with_quad_default",
+        "subtract_quad_scope_default",
         stack_alignv(small_mat) +
             align_dendro() +
             ggtitle("I'm from the parent stack") +
@@ -142,10 +142,10 @@ testthat::test_that("add `with_quad()` works as expected", {
             stack_active() +
             align_dendro() +
             ggtitle("I'm from the parent stack") -
-            with_quad(theme(plot.background = element_rect(fill = "red")))
+            quad_scope(theme(plot.background = element_rect(fill = "red")))
     )
     expect_doppelganger(
-        "subtract_with_quad_set_position_null",
+        "subtract_quad_scope_set_position",
         stack_alignv(small_mat) +
             align_dendro() +
             ggtitle("I'm from the parent stack") +
@@ -159,27 +159,9 @@ testthat::test_that("add `with_quad()` works as expected", {
             stack_active() +
             align_dendro() +
             ggtitle("I'm from the parent stack") -
-            with_quad(
-                theme(plot.background = element_rect(fill = "red")), NULL
-            )
-    )
-    expect_doppelganger(
-        "subtract_with_quad_set_position",
-        stack_alignv(small_mat) +
-            align_dendro() +
-            ggtitle("I'm from the parent stack") +
-            ggheatmap() +
-            anno_top() +
-            align_dendro() +
-            ggtitle("I'm from the nested heatmap") +
-            anno_left() +
-            align_dendro() +
-            ggtitle("I'm from the nested heatmap") +
-            stack_active() +
-            align_dendro() +
-            ggtitle("I'm from the parent stack") -
-            with_quad(
-                theme(plot.background = element_rect(fill = "red")), "l"
+            quad_scope(
+                theme(plot.background = element_rect(fill = "red")),
+                "t"
             )
     )
 })
